@@ -348,7 +348,7 @@ let make_permutation ?(env = Global.env ()) (sigma : Evd.evar_map)
     let nenv = Environ.pop_rel_context (Environ.nb_rel env) env in
     let ctx = List.map Context.Rel.Declaration.drop_body (Environ.rel_context env) in
     let nenv = Environ.push_rel_context ctx nenv in
-    let c' = Reductionops.clos_whd_flags CClosure.all nenv sigma c in
+    let c' = Reductionops.clos_whd_flags RedFlags.all nenv sigma c in
     c'
   in
   let env1 = push_rel_context ctx1 env in
