@@ -331,7 +331,7 @@ let add_wfrec_implicits rec_type c =
                                             qm_name = Anonymous;
                                             qm_record_field = None }
                     in
-                    let newarg = GHole (Evar_kinds.QuestionMark kind, Namegen.IntroAnonymous) in
+                    let newarg = GHole (GQuestionMark kind) in
                     let newarg = DAst.make ?loc newarg in
                     let before, after = List.chop nargs (mapargs args) in
                     let args' = List.append before (newarg :: after) in
@@ -745,7 +745,7 @@ let interp_arity env evd ~poly ~is_rec ~with_evars notations (((loc,i),udecl,rec
   let (arity, impls') =
     let ty = match t with
       | Some ty -> ty
-      | None -> CAst.make ?loc (Constrexpr.CHole (None, Namegen.IntroAnonymous))
+      | None -> CAst.make ?loc (Constrexpr.CHole None)
     in
     Equations_common.evd_comb1 (interp_type_evars_impls env' ?impls:None) evd ty
   in
@@ -865,7 +865,7 @@ let wf_fix_constr env evars sign arity sort carrier cterm crel =
   let sigma, fixty = Typing.type_of env !evars fix in
   let () = evars := sigma in
   let reds =
-    let flags = CClosure.betaiotazeta in
+    let flags = RedFlags.betaiotazeta in
     let csts =
       let ts = TransparentState.empty in
       let cst = Names.Cpred.add (Projection.constant (Lazy.force coq_pr1)) Names.Cpred.empty in
@@ -884,10 +884,10 @@ let wf_fix_constr env evars sign arity sort carrier cterm crel =
            logic_tele_forall_pack;
            logic_tele_forall_unpack]
       in { ts with TransparentState.tr_cst }
-    in CClosure.RedFlags.red_add_transparent flags csts
+    in RedFlags.red_add_transparent flags csts
   in
   let norm env =
-    let infos = Cbv.create_cbv_infos reds env !evars in
+    let infos = Cbv.create_cbv_infos reds ~strong:true env !evars in
     Cbv.cbv_norm infos
   in
   let fixty = norm env fixty in
@@ -902,11 +902,11 @@ let wf_fix_constr env evars sign arity sort carrier cterm crel =
   in
   let fix = norm env fix in
   let functional_type, full_functional_type =
-    let ctx, rest = Reductionops.hnf_decompose_prod_n_decls env !evars (Context.Rel.nhyps sign) functional_type in
+    let ctx, rest = Reductionops.whd_decompose_prod_n_assum env !evars (Context.Rel.nhyps sign) functional_type in
     match kind !evars (whd_all (push_rel_context ctx env) !evars rest) with
     | Prod (na, b, concl) ->
-      let ctx', rest = Reductionops.hnf_decompose_prod_decls (push_rel_context ctx env) !evars b in
-      let infos = Cbv.create_cbv_infos reds (push_rel_context ctx env) !evars in
+      let ctx', rest = Reductionops.whd_decompose_prod_decls (push_rel_context ctx env) !evars b in
+      let infos = Cbv.create_cbv_infos reds ~strong:true (push_rel_context ctx env) !evars in
       let norm = Cbv.cbv_norm infos in
       let fn_type = it_mkProd_or_LetIn rest ctx' in
       let fn_type = norm fn_type in
