@@ -67,8 +67,8 @@ let inductive_info sigma ((mind, _ as ind),u) =
 	arities
     in
     let case c pred brs =
-      let ci = make_case_info (Global.env ()) (mind,i) Sorts.Relevant Constr.RegularStyle in
-      mkCase (EConstr.contract_case env sigma (ci, pred, Constr.NoInvert, c, brs))
+      let ci = make_case_info (Global.env ()) (mind,i) Constr.RegularStyle in
+      mkCase (EConstr.contract_case env sigma (ci, (pred, Sorts.Relevant), Constr.NoInvert, c, brs))
       (* TODO relevance / case inversion *)
     in
       { ind_name = indname;
