@@ -51,10 +51,15 @@ let pi3 (_,_,z) = z
 (** Objects to keep information about equations *)
 
 let cache_rew_rule (base, gr, l2r) =
+  let gr, ((qvars, univs), csts) = UnivGen.fresh_global_instance (Global.env()) gr in
+  let () = if not (Sorts.QVar.Set.is_empty qvars) then
+      CErrors.user_err Pp.(str "Sort polymorphic autorewrite not supported.")
+  in
+  let gru = gr, (univs, csts) in
   Autorewrite.add_rew_rules
     ~locality:Hints.(if Global.sections_are_opened() then Local else SuperGlobal)
     base
-    [CAst.make (UnivGen.fresh_global_instance (Global.env()) gr, true, None)]
+    [CAst.make (gru, true, None)]
 
 let inRewRule =
   let open Libobject in
@@ -287,9 +292,9 @@ let abstract_rec_calls sigma user_obls ?(do_subst=true) is_rec len protos c =
       let case' = mkCase (Inductive.contract_case (Global.env ()) (ci, p, iv, c', brs)) in
         hyps', EConstr.Unsafe.to_constr (EConstr.Vars.substnl proto_fs (succ len) (EConstr.of_constr case'))
 
-    | Proj (p, c) ->
+    | Proj (p, r, c) ->
       let hyps', c' = aux n env hyps c in
-        hyps', mkProj (p, c')
+        hyps', mkProj (p, r, c')
 
     | _ ->
       let f', args = decompose_app c in
@@ -714,7 +719,7 @@ let subst_protos s gr =
     (equations_debug Pp.(fun () -> str"Fixed hint " ++ Printer.pr_econstr_env env sigma term);
      let sigma, _ = Typing.type_of env sigma term in
      let sigma = Evd.minimize_universes sigma in
-     Hints.hint_constr (Evarutil.nf_evar sigma term, Some (Evd.universe_context_set sigma)))
+     Hints.hint_constr (Evarutil.nf_evar sigma term, Some (Evd.sort_context_set sigma)))
   else Hints.hint_globref gr
   [@@ocaml.warning "-3"]
 
@@ -722,7 +727,7 @@ let declare_wf_obligations s info =
   let make_resolve gr =
     equations_debug Pp.(fun () -> str"Declaring wf obligation " ++ Printer.pr_global gr);
     (Hints.empty_hint_info, true,
-     Hints.PathAny, subst_protos s gr)
+     subst_protos s gr)
   in
   let dbname = Principles_proofs.wf_obligations_base info in
   let locality = if Global.sections_are_opened () then Hints.Local else Hints.SuperGlobal in
@@ -1341,7 +1346,7 @@ let declare_funind ~pm info alias env evd is_rec protos progs
     let env = Global.env () in (* refresh *)
     let locality = if Global.sections_are_opened () then Hints.Local else Hints.SuperGlobal in
     Hints.add_hints ~locality [info.term_info.base_id]
-                    (Hints.HintsImmediateEntry [Hints.PathAny, Hints.hint_globref dref]);
+                    (Hints.HintsImmediateEntry [Hints.hint_globref dref]);
     let pm =
       try declare_funelim ~pm info.term_info env evd is_rec protos progs
             ind_stmts all_stmts sign app scope inds kn comb sort dref uctx
@@ -1628,11 +1633,11 @@ let build_equations ~pm with_ind env evd ?(alias:alias option) rec_info progs =
           Nameops.add_suffix indid suff) n) stmts
     in
     let merge_universes_of_constr c =
-      Univ.Level.Set.union (EConstr.universes_of_constr !evd c) in
-    let univs = Univ.Level.Set.union (universes_of_constr !evd arity) univs in
+      Univ.Level.Set.union (snd (EConstr.universes_of_constr !evd c)) in
+    let univs = Univ.Level.Set.union (snd (universes_of_constr !evd arity)) univs in
     let univs = Context.Rel.(fold_outside (Declaration.fold_constr merge_universes_of_constr) sign ~init:univs) in
     let univs =
-      List.fold_left (fun univs c -> Univ.Level.Set.union (universes_of_constr !evd (EConstr.of_constr c)) univs)
+      List.fold_left (fun univs c -> Univ.Level.Set.union (snd (universes_of_constr !evd (EConstr.of_constr c))) univs)
         univs constructors in
     let ind_sort =
       match Retyping.get_sort_family_of env !evd (it_mkProd_or_LetIn arity sign) with
@@ -1674,7 +1679,7 @@ let build_equations ~pm with_ind env evd ?(alias:alias option) rec_info progs =
     let univs, ubinders = Evd.univ_entry ~poly sigma in
     let uctx = match univs with
     | UState.Monomorphic_entry ctx ->
-      let () = DeclareUctx.declare_universe_context ~poly:false ctx in
+      let () = Global.push_context_set ~strict:true ctx in
       Entries.Monomorphic_ind_entry
     | UState.Polymorphic_entry uctx -> Entries.Polymorphic_ind_entry uctx
     in
@@ -1728,7 +1733,7 @@ let build_equations ~pm with_ind env evd ?(alias:alias option) rec_info progs =
     let () =
       List.iteri (fun i ind ->
         let constrs =
-          CList.map_i (fun j _ -> Hints.empty_hint_info, true, Hints.PathAny,
+          CList.map_i (fun j _ -> Hints.empty_hint_info, true,
             Hints.hint_globref (GlobRef.ConstructRef ((kn,i),j))) 1 ind.Entries.mind_entry_lc in
           Hints.add_hints ~locality [info.base_id] (Hints.HintsResolveEntry constrs))
         inds
@@ -1743,7 +1748,7 @@ let build_equations ~pm with_ind env evd ?(alias:alias option) rec_info progs =
     if not poly then
       (* Declare the universe context necessary to typecheck the following
           definitions once and for all. *)
-      (DeclareUctx.declare_universe_context ~poly:false (Evd.universe_context_set !evd);
+      (Global.push_context_set ~strict:true (Evd.universe_context_set !evd);
        evd := Evd.from_env (Global.env ()))
     else ()
   in
