@@ -152,7 +152,7 @@ let derive_subterm ~pm env sigma ~poly (ind, u as indu) =
   let univs, ubinders = Evd.univ_entry ~poly sigma in
   let uctx = match univs with
   | UState.Monomorphic_entry ctx ->
-    let () = DeclareUctx.declare_universe_context ~poly:false ctx in
+    let () = Global.push_context_set ~strict:true ctx in
     Entries.Monomorphic_ind_entry
   | UState.Polymorphic_entry uctx -> Entries.Polymorphic_ind_entry uctx
   in
@@ -177,7 +177,7 @@ let derive_subterm ~pm env sigma ~poly (ind, u as indu) =
     let subind = mkIndU ((k,0), u) in
     let constrhints =
       List.map_i (fun i entry ->
-        List.map_i (fun j _ -> empty_hint_info, true, Hints.PathAny,
+        List.map_i (fun j _ -> empty_hint_info, true,
           Hints.hint_globref (GlobRef.ConstructRef ((k,i),j))) 1 entry.mind_entry_lc)
         0 inds
     in
@@ -207,12 +207,13 @@ let derive_subterm ~pm env sigma ~poly (ind, u as indu) =
           let env' = push_rel_context pars env in
           let subrel =
             let liftindices = List.map (liftn 2 2) indices in
-            let yindices = List.map (subst1 (mkProj (indexproj, mkRel 1))) liftindices in
-            let xindices = List.map (subst1 (mkProj (indexproj, mkRel 2))) liftindices in
+            (* sigma is not sort poly (at least for now) *)
+            let yindices = List.map (subst1 (mkProj (indexproj, Relevant, mkRel 1))) liftindices in
+            let xindices = List.map (subst1 (mkProj (indexproj, Relevant, mkRel 2))) liftindices in
             let apprel =
               applistc subind (extended_rel_list 2 parambinders @
                                  (xindices @ yindices @
-                                    [mkProj (valproj, mkRel 2); mkProj (valproj, mkRel 1)]))
+                                    [mkProj (valproj, Relevant, mkRel 2); mkProj (valproj, Relevant, mkRel 1)]))
             in
             mkLambda (nameR (Id.of_string "x"), typesig,
                       mkLambda (nameR (Id.of_string "y"), lift 1 typesig,
@@ -373,9 +374,9 @@ let derive_below env sigma ~poly (ind,univ as indu) =
         (nargs, bodyB, bodyb)) oneind.mind_nf_lc
     in
     let caseB =
-      mkCase (EConstr.contract_case env !evd (make_case_info env ind Sorts.Relevant RegularStyle, aritylam, NoInvert, mkRel 1, Array.map pi2 branches))
+      mkCase (EConstr.contract_case env !evd (make_case_info env ind RegularStyle, (aritylam, Sorts.Relevant), NoInvert, mkRel 1, Array.map pi2 branches))
     and caseb =
-      mkCase (EConstr.contract_case env !evd (make_case_info env ind Sorts.Relevant RegularStyle, aritylamb, NoInvert, mkRel 1, Array.map pi3 branches))
+      mkCase (EConstr.contract_case env !evd (make_case_info env ind RegularStyle, (aritylamb, Sorts.Relevant), NoInvert, mkRel 1, Array.map pi3 branches))
     in 
       lift 2 (it_mkLambda_or_LetIn caseB argbinders), lift 3 (it_mkLambda_or_LetIn caseb argbinders)
   in
